==> cdi-tck-2.0.6-dist.zip: org/jboss/cdi/tck/tests/lookup/injection/visibility/InjectionVisibilityTest.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2010, Red Hat, Inc., and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.cdi.tck.tests.lookup.injection.visibility;

import static org.jboss.cdi.tck.cdi.Sections.INJECTION_EE;
import static org.testng.Assert.assertEquals;
import static org.testng.Assert.assertNotNull;
import static org.testng.Assert.assertTrue;

import javax.enterprise.inject.spi.Bean;
import javax.inject.Inject;

import org.jboss.arquillian.container.test.api.Deployment;
import org.jboss.cdi.tck.AbstractTest;
import org.jboss.cdi.tck.shrinkwrap.WebArchiveBuilder;
import org.jboss.shrinkwrap.api.spec.WebArchive;
import org.jboss.test.audit.annotations.SpecAssertion;
import org.jboss.test.audit.annotations.SpecVersion;
import org.testng.annotations.Test;

@SpecVersion(spec = "cdi", version = "2.0")
public class InjectionVisibilityTest extends AbstractTest {

    @Deployment
    public static WebArchive createTestArchive() {
        return new WebArchiveBuilder().withTestClassPackage(InjectionVisibilityTest.class).build();
    }

    @Inject
    SimpleSessionBean simpleSessionBean;

    @Test
    @SpecAssertion(section = INJECTION_EE, id = "a")
    public void testPackagePrivateSetMethodInjection() throws Exception {
        Bean<SimpleSessionBean> bean = getUniqueBean(SimpleSessionBean.class);
        assertNotNull(bean.getInjectionPoints());
        assertEquals(bean.getInjectionPoints().size(), 1);
        simpleSessionBean.simpleMethod(); // because of lazy loading
        assertTrue(AbstractBean.fooSetCalled);
    }


}

==> cdi-tck-3.0.2-dist.zip: org/jboss/cdi/tck/tests/lookup/injection/visibility/InjectionVisibilityTest.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2010, Red Hat, Inc., and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.cdi.tck.tests.lookup.injection.visibility;

import static org.jboss.cdi.tck.cdi.Sections.INJECTION_EE;
import static org.testng.Assert.assertEquals;
import static org.testng.Assert.assertNotNull;
import static org.testng.Assert.assertTrue;

import jakarta.enterprise.inject.spi.Bean;
import jakarta.inject.Inject;

import org.jboss.arquillian.container.test.api.Deployment;
import org.jboss.cdi.tck.AbstractTest;
import org.jboss.cdi.tck.shrinkwrap.WebArchiveBuilder;
import org.jboss.shrinkwrap.api.spec.WebArchive;
import org.jboss.test.audit.annotations.SpecAssertion;
import org.jboss.test.audit.annotations.SpecVersion;
import org.testng.annotations.Test;

@SpecVersion(spec = "cdi", version = "2.0")
public class InjectionVisibilityTest extends AbstractTest {

    @Deployment
    public static WebArchive createTestArchive() {
        return new WebArchiveBuilder().withTestClassPackage(InjectionVisibilityTest.class).build();
    }

    @Inject
    SimpleSessionBean simpleSessionBean;

    @Test
    @SpecAssertion(section = INJECTION_EE, id = "a")
    public void testPackagePrivateSetMethodInjection() throws Exception {
        Bean<SimpleSessionBean> bean = getUniqueBean(SimpleSessionBean.class);
        assertNotNull(bean.getInjectionPoints());
        assertEquals(bean.getInjectionPoints().size(), 1);
        simpleSessionBean.simpleMethod(); // because of lazy loading
        assertTrue(AbstractBean.fooSetCalled);
    }


}
